#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import re
import sys

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


def get_version(*file_paths):
    """Retrieves the version from bloxby/__init__.py"""
    filename = os.path.join(os.path.dirname(__file__), *file_paths)
    version_file = open(filename).read()
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError('Unable to find version string.')


version = get_version("bloxby", "__init__.py")

if sys.argv[-1] == 'publish':
    try:
        import wheel

        print("Wheel version: ", wheel.__version__)
    except ImportError:
        print('Wheel library missing. Please run "pip install wheel"')
        sys.exit()
    os.system('python setup.py sdist upload')
    os.system('python setup.py bdist_wheel upload')
    sys.exit()

if sys.argv[-1] == 'tag':
    print("Tagging the version on git:")
    os.system("git tag -a %s -m 'version %s'" % (version, version))
    os.system("git push --tags")
    sys.exit()

readme = open('README.rst').read()

setup(
    name='django-bloxby',
    version=version,
    description="""A django application for bridging bloxby and your django software supporting User creation, package creation and autologin""",
    long_description=readme,
    author='Damilola Adeyemi',
    author_email='adeyemidamilola3@gmail.com',
    url='https://github.com/damey2011/django-bloxby',
    packages=[
        'bloxby',
    ],
    include_package_data=True,
    install_requires=[
        'Django>=2.2',
        'asgiref==3.2.7',
        'beautifulsoup4==4.9.0',
        'bs4==0.0.1',
        'certifi==2020.4.5.1',
        'chardet==3.0.4',
        'idna==2.9',
        'pyftpdlib==1.5.6',
        'pytz==2020.1',
        'requests==2.23.0',
        'soupsieve==1.9.5',
        'sqlparse==0.3.1',
        'urllib3==1.25.9'
    ],
    license="MIT",
    zip_safe=False,
    keywords='django-bloxby',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Framework :: Django :: 2.1',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
)
